@@ -33,15 +33,15 @@ REFERENCES:
 # ****************************************************************************
 import sage.combinat.skew_partition
 from sage.categories.homset import Hom
+from sage.categories.modules_with_basis import ModulesWithBasis
 from sage.categories.morphism import SetMorphism
 from sage.combinat import ribbon_tableau
 from sage.combinat.partition import Partition, Partitions, _Partitions
+from sage.combinat.sf import sfa
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
 from sage.structure.unique_representation import UniqueRepresentation
 
-from . import sfa
-
 # cache for H spin basis
 hsp_to_m_cache = {}
 m_to_hsp_cache = {}
@@ -75,7 +75,7 @@ class LLT_class(UniqueRepresentation):
 
         sage: # needs sage.symbolic
         sage: Symxt = SymmetricFunctions(QQ['x','t'].fraction_field())
-        sage: (x,t) = Symxt.base_ring().gens()
+        sage: x, t = Symxt.base_ring().gens()
         sage: LLT3x = Symxt.llt(3,t=x)
         sage: LLT3 = Symxt.llt(3)
         sage: HS3x = LLT3x.hspin()
@@ -462,7 +462,7 @@ class LLT_generic(sfa.SymmetricFunctionAlgebra_generic):
         sfa.SymmetricFunctionAlgebra_generic.__init__(self, self._sym, self._basis_name)
 
         # temporary until Hom(GradedHopfAlgebrasWithBasis work better)
-        category = sage.categories.all.ModulesWithBasis(self._sym.base_ring())
+        category = ModulesWithBasis(self._sym.base_ring())
         self._m = llt._sym.m()
         self   .register_coercion(SetMorphism(Hom(self._m, self, category), self._m_to_self))
         self._m.register_coercion(SetMorphism(Hom(self, self._m, category), self._self_to_m))
